/**
 * Author   : Davide Ficano
 * Date     : 29-May-05
 */

var ViewSourceWithInputText = {
    ATTR_EDIT_FILE_PATH : "vswEditFilePath",
    ATTR_OLD_FILE_TIME : "vswEditOldFileTime",
    ATTR_EDIT_MODIFIED : "vswEditModified",

    viewText : function(editorData, linkInfo) {
        try {
            var thiz = ViewSourceWithInputText;
            var target = linkInfo.target;
            var generateNewFileName = true;
            var filePath = thiz.makeFileFromInputText(target);

            target.addEventListener("input", thiz.onInput, true);
            if (filePath && filePath.exists()) {
                var check = thiz.checkOverwriteFile();
                if (check == 1) { // cancel
                    return;
                }
                generateNewFileName = check == 2;
            }
            if (generateNewFileName) {
                // always uses the target owner document so inside different
                // frameset elements with same id are correctly handled
                var fileName = ViewSourceWithCommon.getDocumentFileName(
                                                    target.ownerDocument);
                filePath = thiz.generateInputTextFile(target, fileName);
                ViewSourceWithTempCleaner.getTempCleaner()
                        .deleteTemporaryFileOnExit(filePath);
            }

            var text = linkInfo.text;

            ViewSourceWithCommon.saveTextFile(filePath, text);
            editorData.runEditor([filePath.path]);

            target.setAttribute(thiz.ATTR_EDIT_FILE_PATH, filePath.path);
            target.setAttribute(thiz.ATTR_OLD_FILE_TIME, filePath.lastModifiedTime);
            target.removeAttribute(thiz.ATTR_EDIT_MODIFIED);
            target.addEventListener("focus", thiz.onFocusInputText, true);
        } catch (err) {
            ViewSourceWithCommon.log("VSW:viewText error : " + err);
        }
    },

    onInput : function(event) {
        var thiz = ViewSourceWithInputText;
        event.target.setAttribute(thiz.ATTR_EDIT_MODIFIED, "true");
    },

    onFocusInputText : function(event) {
        var thiz = ViewSourceWithInputText;

        var linkInfo = new ViewSourceWithLinkInfo();
        linkInfo.init(window._content.document, thiz.prefs);

        var url = event.target.ownerDocument.location.href;
        var f = function(target, url){
               return function() {
                    ViewSourceWithInputText.fillInputText(target, url);
               };
            }
        setTimeout(f(event.target, url), 400);
        return true;
    },

    generateInputTextFile : function(target, fileName) {
        var thiz = ViewSourceWithInputText;

        var controlName = "";

        if (target) {
            if (target.name) {
                controlName += target.name;
            }
            if (target.id && target.id != controlName) {
                controlName += target.id;
            }
        }

        controlName = ViewSourceWithCommon.getPortableFileName(controlName);
        // replace last extension with .txt
        var re = /\.[^\.]*$/;
        var dateStamp = new Date().getTime();
        var filePath = ViewSourceWithCommon.makeLocalFile(
                            thiz.prefs.destFolder,
                            [fileName.replace(re, controlName + dateStamp + ".txt")]);
        return filePath;

    },

    fillInputText : function(target, url) {
        var thiz = ViewSourceWithInputText;
        var filePath = thiz.makeFileFromInputText(target);

        try {
            if (filePath && filePath.exists()) {
                var currFileTime = filePath.lastModifiedTime;
                var oldFileTime = parseInt(target.getAttribute(thiz.ATTR_OLD_FILE_TIME));
                var isModified = ViewSourceWithCommon.isTrue(
                                    target.getAttribute(thiz.ATTR_EDIT_MODIFIED));

                var reloadFile = false;

                if (currFileTime > oldFileTime) {
                    if (isModified) {
                        if (thiz.checkReload()) {
                            reloadFile = true;
                        } else {
                            target.setAttribute(thiz.ATTR_OLD_FILE_TIME, currFileTime);
                        }
                    } else {
                        reloadFile = true;
                    }
                }

                if (reloadFile) {
                    target.removeEventListener("input", thiz.onInput, true);
                    target.value = ViewSourceWithCommon.loadTextFile(filePath);
                    target.removeAttribute(thiz.ATTR_EDIT_MODIFIED);
                    target.setAttribute(thiz.ATTR_OLD_FILE_TIME, currFileTime);
                    target.addEventListener("input", thiz.onInput, true);
                }
            }
        } catch (err) {
            ViewSourceWithCommon.log("fillInputText: error for file "
                                     + filePath + "\n" + err);
        }
    },

    makeFileFromInputText : function(target) {
        var thiz = ViewSourceWithInputText;
        var filePath = null;

        try {
            var fileName = target.getAttribute(thiz.ATTR_EDIT_FILE_PATH);

            if (fileName && fileName != "") {
                filePath = ViewSourceWithCommon.makeLocalFile(fileName);
            }
        } catch (err) {
        }
        return filePath;
    },

    checkOverwriteFile : function() {
        const nsIPromptSVC = Components.interfaces.nsIPromptService;
        var promptService = Components
                        .classes["@mozilla.org/embedcomp/prompt-service;1"]
                        .getService(nsIPromptSVC);
        var checkResult = { value : 0 };

        var selection = promptService.confirmEx(
            window,
            "ViewSourceWith",
            ViewSourceWithCommon.getLocalizedMessage("overwrite.prompt"),
              (nsIPromptSVC.BUTTON_POS_0 * nsIPromptSVC.BUTTON_TITLE_IS_STRING)
            + (nsIPromptSVC.BUTTON_POS_1 * nsIPromptSVC.BUTTON_TITLE_CANCEL)
            + (nsIPromptSVC.BUTTON_POS_2 * nsIPromptSVC.BUTTON_TITLE_IS_STRING)
            + nsIPromptSVC.BUTTON_POS_1_DEFAULT,
            ViewSourceWithCommon.getLocalizedMessage("overwrite.file"),
            null,
            ViewSourceWithCommon.getLocalizedMessage("open.new.file"),
            null,
            checkResult);

        return selection;
    },

    checkReload : function() {
        const nsIPromptSVC = Components.interfaces.nsIPromptService;
        var promptService = Components
                        .classes["@mozilla.org/embedcomp/prompt-service;1"]
                        .getService(nsIPromptSVC);
        var checkResult = { value : 0 };

        selection = promptService.confirmEx(
            window,
            "ViewSourceWith",
            ViewSourceWithCommon.getLocalizedMessage("reload.modified.text"),
            nsIPromptSVC.STD_YES_NO_BUTTONS
            + nsIPromptSVC.BUTTON_POS_1_DEFAULT,
            null,
            null,
            null,
            null,
            checkResult);

        return selection == 0;
    }
}